smartcard.pyro.server.PyroDaemon.PyroDaemonThread

# ``smartcard`.`pyro`.`server`.`PyroDaemon`.`PyroDaemonThread``

class documentation

`class PyroDaemonThread(Thread):`

View In Hierarchy

Thread running the Pyro daemon server.

Method | `__init__` | Initialize pyro event server with command line arguments. For a complete list of command line arguments, see pyro documentation for pyro-es start script.
Method | `run` | Starts Pyro daemon.
Instance Variable | `daemon` | Undocumented

def __init__(self):

Initialize pyro event server with command line arguments. For a complete list of command line arguments, see pyro documentation for pyro-es start script.

def run(self):

Starts Pyro daemon.

daemon =

Undocumented